<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Ungültiger Ausdruck</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Dunkles Design</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Standardmodus</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Erweiterter Modus</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin Taschenrechner</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin Taschenrechner ist ein einfacher und leicht zu bedienender Taschenrechner. Es unterstützt Addition, Subtraktion, Multiplikation und Division.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Ungültiger Ausdruck</translation>
    </message>
</context>
</TS>